<?php

class CommonHelper {
  /**
   * Return flag counter.
   * @return integer
   */
  public static function getFlagCount($flag_name, $entity_type, $entity_id) {
    $flag_counters = flag_get_counts($entity_type, $entity_id);
    return isset($flag_counters[$flag_name]) ? $flag_counters[$flag_name] : 0;
  }

  /**
   * Return IP geo information.
   * @param string $ip Ip address
   * @return array|NULL
   */
  public static function getIpInfo($ip = NULL) {
    if (!$ip) {
      $ip = ip_address();
    }

    $ipinfo = NULL;

    if ($cache = cache_get('ipinfo:' . $ip)) {
      $ipinfo = $cache->data;
    }
    else {
      $result = drupal_http_request('http://194.85.91.253:8090/geo/geo.html', array(
        'method' => 'POST',
        'data' => '
        <ipquery>
          <fields>
            <all/>
          </fields>
          <ip-list>
            <ip>' . $ip . '</ip>
          </ip-list>
        </ipquery>
      ',
      ));

      if ($result->code == 200) {
        $xml = simplexml_load_string($result->data);
        $ipinfo = (array)$xml->ip;
        if (!isset($ipinfo['message'])) {
          unset($ipinfo['@attributes']);
        }
        cache_set('ipinfo:' . $ip, $ipinfo, REQUEST_TIME + 60*60*24*7);
      }
      else {
        watchdog('druhels', 'Ошибка при получении информации об IP-адресе: <pre>' . check_plain(print_r($result, TRUE)) . '</pre>', NULL, WATCHDOG_ERROR);
      }
    }

    return $ipinfo;
  }

  /**
   * Return DraggableViews entity weight.
   * @param string $view_name View machine name
   * @param integer $entity_id Entity id
   * @return integer
   */
  public static function getDraggableViewsWeight($view_name, $entity_id) {
    static $cache = array();

    $cache_key = $view_name . ':' . $entity_id;

    if (!isset($cache[$cache_key])) {
      $cache[$cache_key] = db_select('draggableviews_structure', 'ds')
        ->fields('ds', array('weight'))
        ->condition('ds.view_name', $view_name)
        ->condition('ds.entity_id', $entity_id)
        ->range(0, 1)
        ->execute()
        ->fetchField();
    }

    return $cache[$cache_key];
  }
}
