<?php

class CsvHelper {
  /**
   * Convert CSV file to array.
   * @param string $csv Path to csv or string with csv data
   * @param array $options Options
   *   - delimiter: Cols delimiter
   *   - enclosure: Col enclosure
   *   - escape: Col escape
   *   - format: Array format - 'assoc' (default), 'keyedAssoc', 'col', 'keyedCol'
   *   - key: Key index or name
   *   - col: Col index or name
   */
  public static function csvToArray($csv, $options = array()) {
    $options += array(
      'delimiter' => ';',
      'enclosure' => '"',
      'escape' => '"',
      'format' => 'assoc',
      'key' => 0,
      'col' => 1,
      'type' => 'file',
      'header' => NULL,
    );
    $array = array();
    $is_file = ($options['type'] == 'file');
    $data = $is_file ? fopen($csv, 'r') : ArrayHelper::getTextLines($csv);

    if (($is_file && $data === FALSE) || (!$is_file && !$data)) {
      return $array;
    }

    if ($options['header'] === NULL) {
      $options['header'] = self::getParsedRow($data, $options);
    }

    if (is_string($options['col'])) {
      $options['col'] = array_search($options['col'], $options['header']);
    }
    if (is_string($options['key'])) {
      $options['key'] = array_search($options['key'], $options['header']);
    }

    $i = 0;
    while (($parsed_row = self::getParsedRow($data, $options)) !== FALSE) {
      // assoc + keyedAssoc
      if ($options['format'] == 'assoc' || $options['format'] == 'keyedAssoc') {
        $row_index = ($options['format'] == 'assoc') ? $i : $parsed_row[$options['key']];
        foreach ($parsed_row as $col_index => $value) {
          $col_name = $options['header'] ? $options['header'][$col_index] : $col_index;
          $array[$row_index][$col_name] = $value;
        }
      }
      // col + keyedCol
      elseif ($options['format'] == 'col' || $options['format'] == 'keyedCol') {
        $row_index = ($options['format'] == 'col') ? $i : $parsed_row[$options['key']];
        $array[$row_index] = $parsed_row[$options['col']];
      }

      $i++;
    }

    if ($is_file) {
      fclose($data);
    }

    return $array;
  }

  /**
   * Return parsed row.
   */
  private static function getParsedRow(&$data, $options) {
    if ($options['type'] == 'file') {
      return fgetcsv($data, NULL, $options['delimiter'], $options['enclosure'], $options['escape']);
    }
    else {
      $row = current($data);
      if ($row === FALSE) {
        return FALSE;
      }
      next($data);
      $parsed_row = str_getcsv($row, $options['delimiter'], $options['enclosure'], $options['escape']);
      return $parsed_row;
    }
  }
}
