<?php

class DrupalHelper {
  /**
   * Return image tag with image style.
   * @param array $image_info Image info from field value table
   * @param string $image_style Image style machine name
   * @return string
   */
  public static function getImageWithStyle($image_info, $image_style) {
    if (!$image_info) {
      return '';
    }

    return theme('image_style', array(
      'style_name' => $image_style,
      'width' => isset($image_info['width']) ? $image_info['width'] : NULL,
      'height' => isset($image_info['height']) ? $image_info['height'] : NULL,
      'path' => $image_info['uri'],
    ));
  }

  /**
   * Mass set variables value.
   * @param array $variables Variables
   */
  public static function setVariables($variables) {
    foreach ($variables as $name => $value) {
      variable_set($name, $value);
    }
  }

  /**
   * Increment variable.
   * @param string $variable_name Variable name
   */
  public static function incrementVariable($variable_name) {
    $variable_value = variable_get($variable_name, 0);
    variable_set($variable_name, $variable_value + 1);
  }

  /**
   * Start timer.
   * @param string $timer_name Timer name
   */
  public static function timerStart($timer_name = 'druhels') {
    timer_start($timer_name);
  }

  /**
   * Stop timer and show value use dsm().
   * @param string $timer_name Timer name
   */
  public static function timerShow($timer_name = 'druhels') {
    dsm(timer_read($timer_name) . ' ms');
  }

  /**
   * Outputs debug information to watchdog.
   * @param mixed $data Debugged data
   * @param string|NULL $label Data label
   */
  public static function debug($data, $label = NULL) {
    static $krumo_header;
    has_krumo();

    $message = krumo_ob($data);

    if ($krumo_header === NULL) {
      if (preg_match('/<style type="text\/css">.*<\/script>/sU', $message, $matches)) {
        $krumo_header = $matches[0];
      }
    }
    else {
      $message .= $krumo_header;
    }

    if ($label) {
      $message = $label . ' => ' . $message;
    }
    watchdog('krumo', $message, NULL, WATCHDOG_DEBUG);
  }

  /**
   * Call dsm() once.
   * @param mixed $data Debugged data
   * @param integer $skip Number of skipped items
   * @param string|NULL $label Data label
   */
  public static function dsmOnce($data, $skip = 0, $label = NULL) {
    static $counter;

    if ($counter == $skip) {
      dsm($data, $label);
    }

    $counter++;
  }

  /**
   * Reorder render array.
   * @param array $build Render array
   * @param array $weights Array of weights
   */
  public static function reorderRenderArray(&$build, $weights) {
    foreach ($weights as $key => $weight) {
      if (isset($build[$key])) {
        $build[$key]['#weight'] = $weight;
      }
    }
    $build['#sorted'] = FALSE;
  }

  /**
   * Render function.
   */
  public static function render($build) {
    return render($build);
  }

  /**
   * Delete ajax html ids from drupal_hmtml_id() static cache.
   */
  public static function clearAjaxHtmlIds() {
    $ajax_html_ids = &drupal_static('drupal_html_id:init');
    $html_ids = &drupal_static('drupal_html_id');
    foreach ($html_ids as $id => $counter) {
      if ($counter == 1) {
        unset($html_ids[$id]);
      }
    }
  }

  /**
   * Return site mail address.
   */
  public static function getSiteMail() {
    return variable_get('site_mail', ini_get('sendmail_from'));
  }

  /**
   * Send mail.
   * @param string $to E-mail "to" address
   * @param string $subject E-mail subject
   * @param string $message E-mail message
   */
  public static function sendMail($to, $subject, $message) {
    return drupal_mail('system', 'mail', $to, language_default(), array(
      'context' => array(
        'subject' => $subject,
        'message' => $message,
      )
    ));
  }

  /**
   * Return current menu item path.
   * @return string
   */
  public static function getMenuItemPath() {
    static $menu_item_path;

    if ($menu_item_path === NULL) {
      $menu_item = menu_get_item();
      if ($menu_item && isset($menu_item['path'])) {
        $menu_item_path = $menu_item['path'];
      }
      else {
        $menu_item_path = '';
      }
    }

    return $menu_item_path;
  }
}
