<?php

class FileHelper {
  /**
   * Return file object by file uri.
   * @param string $uri File uri
   * @return stdClass
   */
  public static function getFileByUri($uri) {
    $files = file_load_multiple(array(), array('uri' => $uri));
    return reset($files);
  }

  /**
  * Return file fid by file uri.
  * @param string $uri File uri
  * @return integer|NULL
  */
  public static function getFileFidByUri($uri) {
    if ($file = self::getFileByUri($uri)) {
      return $file->fid;
    };
  }

  /**
   * Delete file by fid or uri.
   * @param string|integer $file File uri or fid
   * @return boolean
   */
  public static function deleteFile($file) {
    if (is_numeric($file)) {
      $file = file_load($file);
    }
    elseif (is_string($file)) {
      $file = self::getFileByUri($file);
    }
    if ($file) {
      return file_delete($file);
    }
    return FALSE;
  }

  /**
   * Return created file object.
   * @param string $uri File uri
   * @param array $properties File properties
   * @return stdClass
   */
  public static function createFileObject($uri, $properties = array()) {
    $file = $properties + array(
      'uid'      => $GLOBALS['user']->uid,
      'status'   => 0,
      'filename' => drupal_basename($uri),
      'uri'      => $uri,
      'filemime' => file_get_mimetype($uri),
    );
    return (object)$file;
  }

  /**
   * Send file to browser.
   * @param string $content_type Content type
   * @param string $browser_filename Browser filename
   * @param string $file_path File path
   */
  public static function sendFileToBrowser($content_type, $browser_filename, $file_path = NULL) {
    drupal_add_http_header('Content-Type', $content_type);
    drupal_add_http_header('Content-Disposition', 'attachment;filename="' . $browser_filename . '"');

    if ($file_path) {
      readfile($file_path);
    }
  }
}
