<?php

class FormHelper {
  /**
   * Set form placeholder.
   * @param array $element Form element array
   * @param string|NULL $placeholder Placeholder value
   * @param boolean $hide_title Set TRUE if you want hide title
   */
  public static function setPlaceholder(&$element, $placeholder = NULL, $title_display = 'invisible') {
    if (!$placeholder) {
      $placeholder = $element['#title'];
    }
    $element['#attributes']['placeholder'] = $placeholder;

    if ($title_display) {
      $element['#title_display'] = $title_display;
    }
  }

  /**
   * Return options selected values.
   * @param array $options_values Options values
   * @return array
   */
  public static function getOptionsValues($options_values) {
    return array_keys(array_filter($options_values));
  }

  /**
   * Return rendered form.
   * @param string $form_id Form id
   * @return string
   */
  public static function getRenderedForm($form_id) {
    $args = func_get_args();
    $form = call_user_func_array('drupal_get_form', $args);
    return drupal_render($form);
  }

  /**
   * Remove system hidden values from GET form.
   * @param array $form Form array
   * @return array
   */
  public static function prepareGetForm($form) {
    unset($form['form_token']);
    unset($form['form_build_id']);
    unset($form['form_id']);
    unset($form['submit']['#name']);
    return $form;
  }

  /**
   * Recursive remove required flag.
   * @param array $form Form array
   */
  public static function removeRequired(&$form) {
    if (!empty($form['#required'])) {
      $form['#required'] = FALSE;
    }
    foreach (element_children($form) as $key) {
      if (is_array($form[$key])) {
        self::removeRequired($form[$key]);
      }
    }
  }
}
